========
Segtools
========
by Michael Hoffman <michael.hoffman at utoronto dot ca>

License
=======
Segtools is free software: you can redistribute it and/or modify it under the terms of version 2 of the GNU General Public License as published by the Free Software Foundation.

Segtools is distributed in the hope that it will be useful, but WITHOUT
ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.

Python 3 compatibility status
=============================
Segtools is currently partially compatible with Python 3. The following tools can be used:

- segtools-aggregation
- segtools-feature-distance
- segtools-gmtk-parameters
- segtools-length-distribution
- segtools-preprocess

All the other tools as well as these are compatible with Python 2.7